@@ -54,12 +54,7 @@ where
     pub fn new(id: U256, provider: &'a Provider<P>) -> Result<Self, P::Error> {
         // Call the underlying PubsubClient's subscribe
         let rx = provider.as_ref().subscribe(id)?;
-        Ok(Self {
-            id,
-            provider,
-            rx,
-            ret: PhantomData,
-        })
+        Ok(Self { id, provider, rx, ret: PhantomData })
     }
 
     /// Unsubscribes from the subscription.
@@ -108,7 +103,8 @@ impl<'a, P> SubscriptionStream<'a, P, TxHash>
 where
     P: PubsubClient,
 {
-    /// Returns a stream that yields the `Transaction`s for the transaction hashes this stream yields.
+    /// Returns a stream that yields the `Transaction`s for the transaction hashes this stream
+    /// yields.
     ///
     /// This internally calls `Provider::get_transaction` with every new transaction.
     /// No more than n futures will be buffered at any point in time, and less than n may also be
