@@ -24,12 +24,12 @@ if_not_wasm! {
 }
 
 mod http;
-pub use http::Provider as Http;
+pub use http::{ClientError as HttpClientError, Provider as Http};
 
 #[cfg(feature = "ws")]
 mod ws;
 #[cfg(feature = "ws")]
-pub use ws::Ws;
+pub use ws::{ClientError as WsClientError, Ws};
 
 mod quorum;
 pub(crate) use quorum::JsonRpcClientWrapper;
